@@ -1,7 +1,10 @@
 import logging
 
+log = None
 
 def logger(name, logfile, verbosity=3):
+    global log
+
     level = {
         0: logging.ERROR,
         1: logging.WARNING,
@@ -9,6 +12,9 @@ def logger(name, logfile, verbosity=3):
         3: logging.DEBUG
     }.get(verbosity, logging.DEBUG)
 
+    if log:
+        return log
+
     log = logging.getLogger(name=name)
     log.setLevel(level=level)
 
